/* Branch.c generated by valac 0.36.6, the Vala compiler
 * generated from Branch.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <gdk/gdk.h>


#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;
typedef struct _SidebarBranchPrivate SidebarBranchPrivate;

#define FOLDERS_TYPE_BRANCH (folders_branch_get_type ())
#define FOLDERS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLDERS_TYPE_BRANCH, FoldersBranch))
#define FOLDERS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLDERS_TYPE_BRANCH, FoldersBranchClass))
#define FOLDERS_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLDERS_TYPE_BRANCH))
#define FOLDERS_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLDERS_TYPE_BRANCH))
#define FOLDERS_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLDERS_TYPE_BRANCH, FoldersBranchClass))

typedef struct _FoldersBranch FoldersBranch;
typedef struct _FoldersBranchClass FoldersBranchClass;
typedef struct _FoldersBranchPrivate FoldersBranchPrivate;

#define SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY (sidebar_simple_page_entry_get_type ())
#define SIDEBAR_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))

typedef struct _SidebarSimplePageEntry SidebarSimplePageEntry;
typedef struct _SidebarSimplePageEntryClass SidebarSimplePageEntryClass;

#define FOLDERS_TYPE_SIDEBAR_ENTRY (folders_sidebar_entry_get_type ())
#define FOLDERS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry))
#define FOLDERS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntryClass))
#define FOLDERS_IS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLDERS_TYPE_SIDEBAR_ENTRY))
#define FOLDERS_IS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLDERS_TYPE_SIDEBAR_ENTRY))
#define FOLDERS_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntryClass))

typedef struct _FoldersSidebarEntry FoldersSidebarEntry;
typedef struct _FoldersSidebarEntryClass FoldersSidebarEntryClass;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_MEDIA_COLLECTION_REGISTRY (media_collection_registry_get_type ())
#define MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistry))
#define MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))
#define IS_MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_COLLECTION_REGISTRY))
#define IS_MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_COLLECTION_REGISTRY))
#define MEDIA_COLLECTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))

typedef struct _MediaCollectionRegistry MediaCollectionRegistry;
typedef struct _MediaCollectionRegistryClass MediaCollectionRegistryClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _media_collection_registry_unref0(var) ((var == NULL) ? NULL : (var = (media_collection_registry_unref (var), NULL)))

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define SIDEBAR_TYPE_GROUPING (sidebar_grouping_get_type ())
#define SIDEBAR_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_GROUPING, SidebarGrouping))
#define SIDEBAR_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))
#define SIDEBAR_IS_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_IS_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_GROUPING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))

typedef struct _SidebarGrouping SidebarGrouping;
typedef struct _SidebarGroupingClass SidebarGroupingClass;

#define SIDEBAR_TYPE_HEADER (sidebar_header_get_type ())
#define SIDEBAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_HEADER, SidebarHeader))
#define SIDEBAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))
#define SIDEBAR_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))

typedef struct _SidebarHeader SidebarHeader;
typedef struct _SidebarHeaderClass SidebarHeaderClass;

#define FOLDERS_TYPE_ROOT (folders_root_get_type ())
#define FOLDERS_ROOT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLDERS_TYPE_ROOT, FoldersRoot))
#define FOLDERS_ROOT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLDERS_TYPE_ROOT, FoldersRootClass))
#define FOLDERS_IS_ROOT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLDERS_TYPE_ROOT))
#define FOLDERS_IS_ROOT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLDERS_TYPE_ROOT))
#define FOLDERS_ROOT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLDERS_TYPE_ROOT, FoldersRootClass))

typedef struct _FoldersRoot FoldersRoot;
typedef struct _FoldersRootClass FoldersRootClass;

#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;

#define SIDEBAR_BRANCH_TYPE_OPTIONS (sidebar_branch_options_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define SIDEBAR_TYPE_EXPANDABLE_ENTRY (sidebar_expandable_entry_get_type ())
#define SIDEBAR_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntry))
#define SIDEBAR_IS_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY))
#define SIDEBAR_EXPANDABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntryIface))

typedef struct _SidebarExpandableEntry SidebarExpandableEntry;
typedef struct _SidebarExpandableEntryIface SidebarExpandableEntryIface;

#define SIDEBAR_TYPE_RENAMEABLE_ENTRY (sidebar_renameable_entry_get_type ())
#define SIDEBAR_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry))
#define SIDEBAR_IS_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY))
#define SIDEBAR_RENAMEABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntryIface))

typedef struct _SidebarRenameableEntry SidebarRenameableEntry;
typedef struct _SidebarRenameableEntryIface SidebarRenameableEntryIface;
typedef struct _SidebarGroupingPrivate SidebarGroupingPrivate;

#define SIDEBAR_TYPE_EMPHASIZABLE_ENTRY (sidebar_emphasizable_entry_get_type ())
#define SIDEBAR_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntry))
#define SIDEBAR_IS_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY))
#define SIDEBAR_EMPHASIZABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntryIface))

typedef struct _SidebarEmphasizableEntry SidebarEmphasizableEntry;
typedef struct _SidebarEmphasizableEntryIface SidebarEmphasizableEntryIface;
typedef struct _SidebarHeaderPrivate SidebarHeaderPrivate;
typedef struct _FoldersRootPrivate FoldersRootPrivate;

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;
typedef struct _SidebarSimplePageEntryPrivate SidebarSimplePageEntryPrivate;
typedef struct _FoldersSidebarEntryPrivate FoldersSidebarEntryPrivate;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;

#define TYPE_MEDIA_PAGE (media_page_get_type ())
#define MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_PAGE, MediaPage))
#define MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_PAGE, MediaPageClass))
#define IS_MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_PAGE))
#define IS_MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_PAGE))
#define MEDIA_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_PAGE, MediaPageClass))

typedef struct _MediaPage MediaPage;
typedef struct _MediaPageClass MediaPageClass;

#define TYPE_COLLECTION_PAGE (collection_page_get_type ())
#define COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_PAGE, CollectionPage))
#define COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_PAGE, CollectionPageClass))
#define IS_COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_PAGE))
#define IS_COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_PAGE))
#define COLLECTION_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_PAGE, CollectionPageClass))

typedef struct _CollectionPage CollectionPage;
typedef struct _CollectionPageClass CollectionPageClass;

#define FOLDERS_TYPE_PAGE (folders_page_get_type ())
#define FOLDERS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLDERS_TYPE_PAGE, FoldersPage))
#define FOLDERS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLDERS_TYPE_PAGE, FoldersPageClass))
#define FOLDERS_IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLDERS_TYPE_PAGE))
#define FOLDERS_IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLDERS_TYPE_PAGE))
#define FOLDERS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLDERS_TYPE_PAGE, FoldersPageClass))

typedef struct _FoldersPage FoldersPage;
typedef struct _FoldersPageClass FoldersPageClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SidebarBranch {
	GObject parent_instance;
	SidebarBranchPrivate * priv;
};

struct _SidebarBranchClass {
	GObjectClass parent_class;
};

struct _FoldersBranch {
	SidebarBranch parent_instance;
	FoldersBranchPrivate * priv;
};

struct _FoldersBranchClass {
	SidebarBranchClass parent_class;
};

struct _FoldersBranchPrivate {
	GeeHashMap* entries;
	GFile* home_dir;
};

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

typedef enum  {
	SIDEBAR_BRANCH_OPTIONS_NONE = 0,
	SIDEBAR_BRANCH_OPTIONS_HIDE_IF_EMPTY = 1 << 0,
	SIDEBAR_BRANCH_OPTIONS_AUTO_OPEN_ON_NEW_CHILD = 1 << 1,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_EXPAND_TO_FIRST_CHILD = 1 << 2,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING = 1 << 3
} SidebarBranchOptions;

struct _SidebarExpandableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*expand_on_select) (SidebarExpandableEntry* self);
};

struct _SidebarRenameableEntryIface {
	GTypeInterface parent_iface;
	void (*rename) (SidebarRenameableEntry* self, const gchar* new_name);
	gboolean (*is_user_renameable) (SidebarRenameableEntry* self);
};

struct _SidebarGrouping {
	GObject parent_instance;
	SidebarGroupingPrivate * priv;
};

struct _SidebarGroupingClass {
	GObjectClass parent_class;
};

struct _SidebarEmphasizableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*is_emphasized) (SidebarEmphasizableEntry* self);
};

struct _SidebarHeader {
	SidebarGrouping parent_instance;
	SidebarHeaderPrivate * priv;
};

struct _SidebarHeaderClass {
	SidebarGroupingClass parent_class;
};

struct _FoldersRoot {
	SidebarHeader parent_instance;
	FoldersRootPrivate * priv;
};

struct _FoldersRootClass {
	SidebarHeaderClass parent_class;
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _SidebarSimplePageEntry {
	GObject parent_instance;
	SidebarSimplePageEntryPrivate * priv;
};

struct _SidebarSimplePageEntryClass {
	GObjectClass parent_class;
	gchar* (*get_sidebar_name) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_icon) (SidebarSimplePageEntry* self);
	gchar* (*to_string) (SidebarSimplePageEntry* self);
	Page* (*create_page) (SidebarSimplePageEntry* self);
};

struct _FoldersSidebarEntry {
	SidebarSimplePageEntry parent_instance;
	FoldersSidebarEntryPrivate * priv;
};

struct _FoldersSidebarEntryClass {
	SidebarSimplePageEntryClass parent_class;
};

struct _FoldersSidebarEntryPrivate {
	GFile* _dir;
	gchar* _collation;
	gint _count;
};


static gpointer folders_branch_parent_class = NULL;
static gpointer folders_root_parent_class = NULL;
static gpointer folders_sidebar_entry_parent_class = NULL;
extern gchar* folders_icon;
extern gchar* folders_have_photos_icon;
static SidebarExpandableEntryIface * folders_sidebar_entry_sidebar_expandable_entry_parent_iface = NULL;

GType sidebar_branch_get_type (void) G_GNUC_CONST;
GType folders_branch_get_type (void) G_GNUC_CONST;
GType sidebar_simple_page_entry_get_type (void) G_GNUC_CONST;
GType folders_sidebar_entry_get_type (void) G_GNUC_CONST;
#define FOLDERS_BRANCH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), FOLDERS_TYPE_BRANCH, FoldersBranchPrivate))
enum  {
	FOLDERS_BRANCH_DUMMY_PROPERTY
};
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
gpointer media_collection_registry_ref (gpointer instance);
void media_collection_registry_unref (gpointer instance);
GParamSpec* param_spec_media_collection_registry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_collection_registry (GValue* value, gpointer v_object);
void value_take_media_collection_registry (GValue* value, gpointer v_object);
gpointer value_get_media_collection_registry (const GValue* value);
GType media_collection_registry_get_type (void) G_GNUC_CONST;
MediaCollectionRegistry* media_collection_registry_get_instance (void);
GeeCollection* media_collection_registry_get_all (MediaCollectionRegistry* self);
GType data_object_get_type (void) G_GNUC_CONST;
static void folders_branch_on_media_contents_altered (FoldersBranch* self, GeeIterable* added, GeeIterable* removed);
static void _folders_branch_on_media_contents_altered_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
guint file_hash (GFile* file);
static guint _file_hash_gee_hash_data_func (gconstpointer v, gpointer self);
gboolean file_equal (GFile* a, GFile* b);
static gboolean _file_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
FoldersBranch* folders_branch_new (void);
FoldersBranch* folders_branch_construct (GType object_type);
FoldersRoot* folders_root_new (void);
FoldersRoot* folders_root_construct (GType object_type);
GType sidebar_grouping_get_type (void) G_GNUC_CONST;
GType sidebar_header_get_type (void) G_GNUC_CONST;
GType folders_root_get_type (void) G_GNUC_CONST;
GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
GType sidebar_branch_options_get_type (void) G_GNUC_CONST;
static gint folders_branch_comparator (SidebarEntry* a, SidebarEntry* b);
static gint _folders_branch_comparator_gcompare_func (gconstpointer a, gconstpointer b);
SidebarBranch* sidebar_branch_new (SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
SidebarBranch* sidebar_branch_construct (GType object_type, SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
GeeCollection* data_collection_get_all (DataCollection* self);
const gchar* folders_sidebar_entry_get_collation (FoldersSidebarEntry* self);
gchar* sidebar_simple_page_entry_get_sidebar_name (SidebarSimplePageEntry* self);
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
static void folders_branch_on_master_source_replaced (FoldersBranch* self, MediaSource* media_source, GFile* old_file, GFile* new_file);
static void folders_branch_remove_entry (FoldersBranch* self, GFile* file);
static void folders_branch_add_entry (FoldersBranch* self, MediaSource* media);
static void _folders_branch_on_master_source_replaced_media_source_master_replaced (MediaSource* _sender, GFile* old_file, GFile* new_file, gpointer self);
GFile* media_source_get_file (MediaSource* self);
FoldersSidebarEntry* folders_sidebar_entry_new (GFile* dir);
FoldersSidebarEntry* folders_sidebar_entry_construct (GType object_type, GFile* dir);
SidebarEntry* sidebar_branch_get_root (SidebarBranch* self);
void sidebar_branch_graft (SidebarBranch* self, SidebarEntry* parent, SidebarEntry* entry, GCompareFunc comparator);
gint folders_sidebar_entry_get_count (FoldersSidebarEntry* self);
void folders_sidebar_entry_set_count (FoldersSidebarEntry* self, gint value);
gint sidebar_branch_get_child_count (SidebarBranch* self, SidebarEntry* parent);
GFile* folders_sidebar_entry_get_dir (FoldersSidebarEntry* self);
SidebarEntry* sidebar_branch_get_parent (SidebarBranch* self, SidebarEntry* entry);
void sidebar_branch_prune (SidebarBranch* self, SidebarEntry* entry);
static void folders_branch_finalize (GObject * obj);
GType sidebar_expandable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_renameable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_emphasizable_entry_get_type (void) G_GNUC_CONST;
enum  {
	FOLDERS_ROOT_DUMMY_PROPERTY
};
SidebarHeader* sidebar_header_new (const gchar* name, gboolean emphasized);
SidebarHeader* sidebar_header_construct (GType object_type, const gchar* name, gboolean emphasized);
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
#define FOLDERS_SIDEBAR_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntryPrivate))
enum  {
	FOLDERS_SIDEBAR_ENTRY_DUMMY_PROPERTY,
	FOLDERS_SIDEBAR_ENTRY_DIR_PROPERTY,
	FOLDERS_SIDEBAR_ENTRY_COLLATION_PROPERTY,
	FOLDERS_SIDEBAR_ENTRY_COUNT_PROPERTY
};
SidebarSimplePageEntry* sidebar_simple_page_entry_construct (GType object_type);
static void folders_sidebar_entry_set_dir (FoldersSidebarEntry* self, GFile* value);
gchar* g_utf8_collate_key_for_filename (const gchar* str, gssize len);
static void folders_sidebar_entry_set_collation (FoldersSidebarEntry* self, const gchar* value);
static gchar* folders_sidebar_entry_real_get_sidebar_name (SidebarSimplePageEntry* base);
static gchar* folders_sidebar_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base);
static gchar* folders_sidebar_entry_real_to_string (SidebarSimplePageEntry* base);
static gboolean folders_sidebar_entry_real_expand_on_select (SidebarExpandableEntry* base);
static Page* folders_sidebar_entry_real_create_page (SidebarSimplePageEntry* base);
FoldersPage* folders_page_new (GFile* dir);
FoldersPage* folders_page_construct (GType object_type, GFile* dir);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType media_page_get_type (void) G_GNUC_CONST;
GType collection_page_get_type (void) G_GNUC_CONST;
GType folders_page_get_type (void) G_GNUC_CONST;
gchar* sidebar_simple_page_entry_get_sidebar_icon (SidebarSimplePageEntry* self);
static void folders_sidebar_entry_finalize (GObject * obj);
static void _vala_folders_sidebar_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_folders_sidebar_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static void _folders_branch_on_media_contents_altered_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 31 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_branch_on_media_contents_altered ((FoldersBranch*) self, added, removed);
#line 564 "Branch.c"
}


static guint _file_hash_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = file_hash ((GFile*) v);
#line 8 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 573 "Branch.c"
}


static gboolean _file_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = file_equal ((GFile*) a, (GFile*) b);
#line 8 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 582 "Branch.c"
}


static gint _folders_branch_comparator_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = folders_branch_comparator ((SidebarEntry*) a, (SidebarEntry*) b);
#line 13 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 591 "Branch.c"
}


FoldersBranch* folders_branch_construct (GType object_type) {
	FoldersBranch * self = NULL;
	FoldersRoot* _tmp0_;
	FoldersRoot* _tmp1_;
	const gchar* _tmp2_;
	GFile* _tmp3_;
#line 13 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = folders_root_new ();
#line 13 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = (FoldersBranch*) sidebar_branch_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SIDEBAR_TYPE_ENTRY, SidebarEntry), SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING | SIDEBAR_BRANCH_OPTIONS_HIDE_IF_EMPTY, _folders_branch_comparator_gcompare_func, NULL);
#line 13 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (_tmp1_);
#line 18 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp2_ = g_get_home_dir ();
#line 18 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp3_ = g_file_new_for_path (_tmp2_);
#line 18 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (self->priv->home_dir);
#line 18 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self->priv->home_dir = _tmp3_;
#line 617 "Branch.c"
	{
		GeeIterator* _sources_it = NULL;
		MediaCollectionRegistry* _tmp4_;
		MediaCollectionRegistry* _tmp5_;
		GeeCollection* _tmp6_;
		GeeCollection* _tmp7_;
		GeeIterator* _tmp8_;
		GeeIterator* _tmp9_;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp4_ = media_collection_registry_get_instance ();
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp5_ = _tmp4_;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp6_ = media_collection_registry_get_all (_tmp5_);
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp7_ = _tmp6_;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp8_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ITERABLE, GeeIterable));
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp9_ = _tmp8_;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (_tmp7_);
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_media_collection_registry_unref0 (_tmp5_);
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_sources_it = _tmp9_;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		while (TRUE) {
#line 646 "Branch.c"
			GeeIterator* _tmp10_;
			gboolean _tmp11_;
			MediaSourceCollection* sources = NULL;
			GeeIterator* _tmp12_;
			gpointer _tmp13_;
			MediaSourceCollection* _tmp14_;
			GeeCollection* _tmp15_;
			GeeCollection* _tmp16_;
			MediaSourceCollection* _tmp17_;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp10_ = _sources_it;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp11_ = gee_iterator_next (_tmp10_);
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (!_tmp11_) {
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				break;
#line 664 "Branch.c"
			}
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp12_ = _sources_it;
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp13_ = gee_iterator_get (_tmp12_);
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			sources = (MediaSourceCollection*) _tmp13_;
#line 22 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp14_ = sources;
#line 22 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp15_ = data_collection_get_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_DATA_COLLECTION, DataCollection));
#line 22 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp16_ = _tmp15_;
#line 22 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			folders_branch_on_media_contents_altered (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ITERABLE, GeeIterable), NULL);
#line 22 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_g_object_unref0 (_tmp16_);
#line 25 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp17_ = sources;
#line 25 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _folders_branch_on_media_contents_altered_data_collection_contents_altered, self, 0);
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_data_collection_unref0 (sources);
#line 688 "Branch.c"
		}
#line 20 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (_sources_it);
#line 692 "Branch.c"
	}
#line 12 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return self;
#line 696 "Branch.c"
}


FoldersBranch* folders_branch_new (void) {
#line 12 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return folders_branch_construct (FOLDERS_TYPE_BRANCH);
#line 703 "Branch.c"
}


static gint folders_branch_comparator (SidebarEntry* a, SidebarEntry* b) {
	gint result = 0;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	gint coll_key_equality = 0;
	GCompareFunc _tmp2_;
	SidebarEntry* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	SidebarEntry* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
#line 34 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (a), 0);
#line 34 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (b), 0);
#line 35 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = a;
#line 35 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = b;
#line 35 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp0_ == _tmp1_) {
#line 36 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		result = 0;
#line 36 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		return result;
#line 735 "Branch.c"
	}
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp2_ = g_strcmp0;
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp3_ = a;
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp4_ = folders_sidebar_entry_get_collation (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry));
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp5_ = _tmp4_;
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp6_ = b;
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp7_ = folders_sidebar_entry_get_collation (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry));
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp8_ = _tmp7_;
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp9_ = _tmp2_ (_tmp5_, _tmp8_);
#line 38 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	coll_key_equality = _tmp9_;
#line 41 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp10_ = coll_key_equality;
#line 41 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp10_ == 0) {
#line 759 "Branch.c"
		GCompareFunc _tmp11_;
		SidebarEntry* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		SidebarEntry* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp11_ = g_strcmp0;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp12_ = a;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp13_ = sidebar_simple_page_entry_get_sidebar_name (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry));
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp14_ = _tmp13_;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp15_ = b;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp16_ = sidebar_simple_page_entry_get_sidebar_name (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry));
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp17_ = _tmp16_;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp18_ = _tmp11_ (_tmp14_, _tmp17_);
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp19_ = _tmp18_;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_free0 (_tmp17_);
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_free0 (_tmp14_);
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		result = _tmp19_;
#line 44 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		return result;
#line 795 "Branch.c"
	}
#line 48 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = coll_key_equality;
#line 48 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 801 "Branch.c"
}


static void folders_branch_on_master_source_replaced (FoldersBranch* self, MediaSource* media_source, GFile* old_file, GFile* new_file) {
	GFile* _tmp0_;
	MediaSource* _tmp1_;
#line 51 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_BRANCH (self));
#line 51 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (IS_MEDIA_SOURCE (media_source));
#line 51 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (G_IS_FILE (old_file));
#line 51 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (G_IS_FILE (new_file));
#line 52 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = old_file;
#line 52 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_branch_remove_entry (self, _tmp0_);
#line 53 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = media_source;
#line 53 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_branch_add_entry (self, _tmp1_);
#line 824 "Branch.c"
}


static void _folders_branch_on_master_source_replaced_media_source_master_replaced (MediaSource* _sender, GFile* old_file, GFile* new_file, gpointer self) {
#line 60 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_branch_on_master_source_replaced ((FoldersBranch*) self, _sender, old_file, new_file);
#line 831 "Branch.c"
}


static void folders_branch_on_media_contents_altered (FoldersBranch* self, GeeIterable* added, GeeIterable* removed) {
	GeeIterable* _tmp0_;
	GeeIterable* _tmp9_;
#line 56 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_BRANCH (self));
#line 56 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail ((added == NULL) || GEE_IS_ITERABLE (added));
#line 56 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_ITERABLE (removed));
#line 57 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = added;
#line 57 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp0_ != NULL) {
#line 848 "Branch.c"
		{
			GeeIterator* _object_it = NULL;
			GeeIterable* _tmp1_;
			GeeIterator* _tmp2_;
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp1_ = added;
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp2_ = gee_iterable_iterator (_tmp1_);
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_object_it = _tmp2_;
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			while (TRUE) {
#line 861 "Branch.c"
				GeeIterator* _tmp3_;
				gboolean _tmp4_;
				DataObject* object = NULL;
				GeeIterator* _tmp5_;
				gpointer _tmp6_;
				DataObject* _tmp7_;
				DataObject* _tmp8_;
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp3_ = _object_it;
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp4_ = gee_iterator_next (_tmp3_);
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				if (!_tmp4_) {
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					break;
#line 877 "Branch.c"
				}
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp5_ = _object_it;
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp6_ = gee_iterator_get (_tmp5_);
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				object = (DataObject*) _tmp6_;
#line 59 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp7_ = object;
#line 59 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				folders_branch_add_entry (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_MEDIA_SOURCE, MediaSource));
#line 60 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp8_ = object;
#line 60 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_MEDIA_SOURCE, MediaSource), "master-replaced", (GCallback) _folders_branch_on_master_source_replaced_media_source_master_replaced, self, 0);
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (object);
#line 895 "Branch.c"
			}
#line 58 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_g_object_unref0 (_object_it);
#line 899 "Branch.c"
		}
	}
#line 64 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp9_ = removed;
#line 64 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp9_ != NULL) {
#line 906 "Branch.c"
		{
			GeeIterator* _object_it = NULL;
			GeeIterable* _tmp10_;
			GeeIterator* _tmp11_;
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp10_ = removed;
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp11_ = gee_iterable_iterator (_tmp10_);
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_object_it = _tmp11_;
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			while (TRUE) {
#line 919 "Branch.c"
				GeeIterator* _tmp12_;
				gboolean _tmp13_;
				DataObject* object = NULL;
				GeeIterator* _tmp14_;
				gpointer _tmp15_;
				DataObject* _tmp16_;
				GFile* _tmp17_;
				GFile* _tmp18_;
				DataObject* _tmp19_;
				guint _tmp20_;
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp12_ = _object_it;
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp13_ = gee_iterator_next (_tmp12_);
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				if (!_tmp13_) {
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					break;
#line 938 "Branch.c"
				}
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp14_ = _object_it;
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp15_ = gee_iterator_get (_tmp14_);
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				object = (DataObject*) _tmp15_;
#line 66 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp16_ = object;
#line 66 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp17_ = media_source_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_MEDIA_SOURCE, MediaSource));
#line 66 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp18_ = _tmp17_;
#line 66 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				folders_branch_remove_entry (self, _tmp18_);
#line 66 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (_tmp18_);
#line 67 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp19_ = object;
#line 67 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				g_signal_parse_name ("master-replaced", TYPE_MEDIA_SOURCE, &_tmp20_, NULL, FALSE);
#line 67 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_MEDIA_SOURCE, MediaSource), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp20_, 0, NULL, (GCallback) _folders_branch_on_master_source_replaced_media_source_master_replaced, self);
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (object);
#line 964 "Branch.c"
			}
#line 65 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_g_object_unref0 (_object_it);
#line 968 "Branch.c"
		}
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 96 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return self ? g_object_ref (self) : NULL;
#line 977 "Branch.c"
}


static void folders_branch_add_entry (FoldersBranch* self, MediaSource* media) {
	GFile* file = NULL;
	MediaSource* _tmp0_;
	GFile* _tmp1_;
	GeeArrayList* elements = NULL;
	GeeArrayList* _tmp2_;
	GFile* parent = NULL;
	GFile* _tmp3_;
	GFile* _tmp4_;
	FoldersSidebarEntry* parent_entry = NULL;
#line 72 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_BRANCH (self));
#line 72 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (IS_MEDIA_SOURCE (media));
#line 73 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = media;
#line 73 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = media_source_get_file (_tmp0_);
#line 73 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	file = _tmp1_;
#line 75 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp2_ = gee_array_list_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 75 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	elements = _tmp2_;
#line 78 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp3_ = file;
#line 78 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp4_ = g_file_get_parent (_tmp3_);
#line 78 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	parent = _tmp4_;
#line 79 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	while (TRUE) {
#line 1013 "Branch.c"
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
		GFile* _tmp8_;
		GFile* _tmp9_;
		gboolean _tmp10_;
		gboolean _tmp11_;
		GeeArrayList* _tmp12_;
		GFile* _tmp13_;
		GFile* _tmp14_;
		GFile* _tmp15_;
#line 79 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp5_ = parent;
#line 79 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		if (!(_tmp5_ != NULL)) {
#line 79 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			break;
#line 1031 "Branch.c"
		}
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp6_ = parent;
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp7_ = self->priv->home_dir;
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp8_ = g_file_get_parent (_tmp7_);
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp9_ = _tmp8_;
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp10_ = g_file_equal (_tmp6_, _tmp9_);
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp11_ = _tmp10_;
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (_tmp9_);
#line 81 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		if (_tmp11_) {
#line 82 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			break;
#line 1051 "Branch.c"
		}
#line 84 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp12_ = elements;
#line 84 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp13_ = parent;
#line 84 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp13_);
#line 86 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp14_ = parent;
#line 86 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp15_ = g_file_get_parent (_tmp14_);
#line 86 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (parent);
#line 86 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		parent = _tmp15_;
#line 1067 "Branch.c"
	}
#line 91 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	parent_entry = NULL;
#line 1071 "Branch.c"
	{
		gint ctr = 0;
		GeeArrayList* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp16_ = elements;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp17_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp18_ = _tmp17_;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		ctr = _tmp18_ - 1;
#line 1085 "Branch.c"
		{
			gboolean _tmp19_ = FALSE;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp19_ = TRUE;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			while (TRUE) {
#line 1092 "Branch.c"
				gint _tmp21_;
				GFile* parent_dir = NULL;
				GeeArrayList* _tmp22_;
				gint _tmp23_;
				gpointer _tmp24_;
				FoldersSidebarEntry* old_parent_entry = NULL;
				FoldersSidebarEntry* _tmp25_;
				FoldersSidebarEntry* _tmp26_;
				GeeHashMap* _tmp27_;
				GFile* _tmp28_;
				gpointer _tmp29_;
				FoldersSidebarEntry* _tmp30_;
				gint _tmp42_;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				if (!_tmp19_) {
#line 1108 "Branch.c"
					gint _tmp20_;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp20_ = ctr;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					ctr = _tmp20_ - 1;
#line 1114 "Branch.c"
				}
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp19_ = FALSE;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp21_ = ctr;
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				if (!(_tmp21_ >= 0)) {
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					break;
#line 1124 "Branch.c"
				}
#line 93 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp22_ = elements;
#line 93 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp23_ = ctr;
#line 93 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp24_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp23_);
#line 93 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				parent_dir = (GFile*) _tmp24_;
#line 96 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp25_ = parent_entry;
#line 96 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp26_ = _g_object_ref0 (_tmp25_);
#line 96 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				old_parent_entry = _tmp26_;
#line 98 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp27_ = self->priv->entries;
#line 98 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp28_ = parent_dir;
#line 98 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp29_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp28_);
#line 98 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (parent_entry);
#line 98 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				parent_entry = (FoldersSidebarEntry*) _tmp29_;
#line 99 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp30_ = parent_entry;
#line 99 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				if (_tmp30_ == NULL) {
#line 1154 "Branch.c"
					GFile* _tmp31_;
					FoldersSidebarEntry* _tmp32_;
					GeeHashMap* _tmp33_;
					GFile* _tmp34_;
					FoldersSidebarEntry* _tmp35_;
					SidebarEntry* _tmp36_ = NULL;
					FoldersSidebarEntry* _tmp37_;
					FoldersSidebarEntry* _tmp41_;
#line 100 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp31_ = parent_dir;
#line 100 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp32_ = folders_sidebar_entry_new (_tmp31_);
#line 100 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_g_object_unref0 (parent_entry);
#line 100 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					parent_entry = _tmp32_;
#line 101 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp33_ = self->priv->entries;
#line 101 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp34_ = parent_dir;
#line 101 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp35_ = parent_entry;
#line 101 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp34_, _tmp35_);
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp37_ = old_parent_entry;
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					if (_tmp37_ == NULL) {
#line 1183 "Branch.c"
						SidebarEntry* _tmp38_;
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_tmp38_ = sidebar_branch_get_root (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch));
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_g_object_unref0 (_tmp36_);
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_tmp36_ = _tmp38_;
#line 1191 "Branch.c"
					} else {
						FoldersSidebarEntry* _tmp39_;
						SidebarEntry* _tmp40_;
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_tmp39_ = old_parent_entry;
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_tmp40_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_g_object_unref0 (_tmp36_);
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
						_tmp36_ = _tmp40_;
#line 1203 "Branch.c"
					}
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp41_ = parent_entry;
#line 103 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					sidebar_branch_graft (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), _tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, SIDEBAR_TYPE_ENTRY, SidebarEntry), NULL);
#line 99 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_g_object_unref0 (_tmp36_);
#line 1211 "Branch.c"
				}
#line 107 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp42_ = ctr;
#line 107 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				if (_tmp42_ == 0) {
#line 1217 "Branch.c"
					FoldersSidebarEntry* _tmp43_;
					gint _tmp44_;
					gint _tmp45_;
#line 108 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp43_ = parent_entry;
#line 108 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp44_ = folders_sidebar_entry_get_count (_tmp43_);
#line 108 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					_tmp45_ = _tmp44_;
#line 108 "/home/jens/Source/shotwell/src/folders/Branch.vala"
					folders_sidebar_entry_set_count (_tmp43_, _tmp45_ + 1);
#line 1229 "Branch.c"
				}
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (old_parent_entry);
#line 92 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (parent_dir);
#line 1235 "Branch.c"
			}
		}
	}
#line 72 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (parent_entry);
#line 72 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (parent);
#line 72 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (elements);
#line 72 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (file);
#line 1247 "Branch.c"
}


static void folders_branch_remove_entry (FoldersBranch* self, GFile* file) {
	FoldersSidebarEntry* folder_entry = NULL;
	GeeHashMap* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	gpointer _tmp4_;
	FoldersSidebarEntry* _tmp5_;
	FoldersSidebarEntry* _tmp6_;
	FoldersSidebarEntry* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	gboolean _tmp10_ = FALSE;
	FoldersSidebarEntry* _tmp11_;
	FoldersSidebarEntry* _tmp12_;
	gint _tmp13_;
	gint _tmp14_;
	FoldersSidebarEntry* prune_point = NULL;
	FoldersSidebarEntry* _tmp17_;
	FoldersSidebarEntry* _tmp18_;
	FoldersSidebarEntry* _tmp19_;
	FoldersSidebarEntry* _tmp40_;
#line 112 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_BRANCH (self));
#line 112 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->entries;
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = file;
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp2_ = g_file_get_parent (_tmp1_);
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp3_ = _tmp2_;
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp4_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp3_);
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp5_ = (FoldersSidebarEntry*) _tmp4_;
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (_tmp3_);
#line 113 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folder_entry = _tmp5_;
#line 114 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp6_ = folder_entry;
#line 114 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp6_ == NULL) {
#line 115 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (folder_entry);
#line 115 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		return;
#line 1301 "Branch.c"
	}
#line 117 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp7_ = folder_entry;
#line 117 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp8_ = folders_sidebar_entry_get_count (_tmp7_);
#line 117 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp9_ = _tmp8_;
#line 117 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_vala_assert (_tmp9_ > 0, "folder_entry.count > 0");
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp11_ = folder_entry;
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp12_ = folder_entry;
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp13_ = folders_sidebar_entry_get_count (_tmp12_);
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp14_ = _tmp13_;
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_sidebar_entry_set_count (_tmp12_, _tmp14_ - 1);
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if ((_tmp14_ - 1) > 0) {
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp10_ = TRUE;
#line 1325 "Branch.c"
	} else {
		FoldersSidebarEntry* _tmp15_;
		gint _tmp16_;
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp15_ = folder_entry;
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp16_ = sidebar_branch_get_child_count (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp10_ = _tmp16_ > 0;
#line 1335 "Branch.c"
	}
#line 120 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp10_) {
#line 121 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (folder_entry);
#line 121 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		return;
#line 1343 "Branch.c"
	}
#line 124 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp17_ = folder_entry;
#line 124 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp18_ = _g_object_ref0 (_tmp17_);
#line 124 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	prune_point = _tmp18_;
#line 125 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp19_ = prune_point;
#line 125 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_vala_assert (_tmp19_ != NULL, "prune_point != null");
#line 1355 "Branch.c"
	{
		gboolean _tmp20_ = FALSE;
#line 127 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp20_ = TRUE;
#line 127 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		while (TRUE) {
#line 1362 "Branch.c"
			gboolean removed = FALSE;
			GeeHashMap* _tmp21_;
			FoldersSidebarEntry* _tmp22_;
			GFile* _tmp23_;
			GFile* _tmp24_;
			gboolean _tmp25_;
			gboolean _tmp26_;
			FoldersSidebarEntry* parent = NULL;
			FoldersSidebarEntry* _tmp27_;
			SidebarEntry* _tmp28_;
			FoldersSidebarEntry* _tmp29_;
			gboolean _tmp30_ = FALSE;
			gboolean _tmp31_ = FALSE;
			FoldersSidebarEntry* _tmp32_;
			FoldersSidebarEntry* _tmp38_;
			FoldersSidebarEntry* _tmp39_;
#line 127 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (!_tmp20_) {
#line 1381 "Branch.c"
			}
#line 127 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp20_ = FALSE;
#line 128 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp21_ = self->priv->entries;
#line 128 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp22_ = prune_point;
#line 128 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp23_ = folders_sidebar_entry_get_dir (_tmp22_);
#line 128 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp24_ = _tmp23_;
#line 128 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp25_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp24_, NULL);
#line 128 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			removed = _tmp25_;
#line 129 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp26_ = removed;
#line 129 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_vala_assert (_tmp26_, "removed");
#line 131 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp27_ = prune_point;
#line 131 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp28_ = sidebar_branch_get_parent (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 131 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp29_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, FOLDERS_TYPE_SIDEBAR_ENTRY) ? ((FoldersSidebarEntry*) _tmp28_) : NULL;
#line 131 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (_tmp29_ == NULL) {
#line 131 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (_tmp28_);
#line 1411 "Branch.c"
			}
#line 131 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			parent = _tmp29_;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp32_ = parent;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (_tmp32_ == NULL) {
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp31_ = TRUE;
#line 1421 "Branch.c"
			} else {
				FoldersSidebarEntry* _tmp33_;
				gint _tmp34_;
				gint _tmp35_;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp33_ = parent;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp34_ = folders_sidebar_entry_get_count (_tmp33_);
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp35_ = _tmp34_;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp31_ = _tmp35_ != 0;
#line 1434 "Branch.c"
			}
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (_tmp31_) {
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp30_ = TRUE;
#line 1440 "Branch.c"
			} else {
				FoldersSidebarEntry* _tmp36_;
				gint _tmp37_;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp36_ = parent;
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp37_ = sidebar_branch_get_child_count (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_tmp30_ = _tmp37_ > 1;
#line 1450 "Branch.c"
			}
#line 132 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (_tmp30_) {
#line 133 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				_g_object_unref0 (parent);
#line 133 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				break;
#line 1458 "Branch.c"
			}
#line 135 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp38_ = parent;
#line 135 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp39_ = _g_object_ref0 (_tmp38_);
#line 135 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_g_object_unref0 (prune_point);
#line 135 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			prune_point = _tmp39_;
#line 127 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_g_object_unref0 (parent);
#line 1470 "Branch.c"
		}
	}
#line 138 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp40_ = prune_point;
#line 138 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	sidebar_branch_prune (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 112 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (prune_point);
#line 112 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (folder_entry);
#line 1481 "Branch.c"
}


static void folders_branch_class_init (FoldersBranchClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_branch_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_type_class_add_private (klass, sizeof (FoldersBranchPrivate));
#line 7 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = folders_branch_finalize;
#line 1492 "Branch.c"
}


static void folders_branch_instance_init (FoldersBranch * self) {
	GeeHashMap* _tmp0_;
#line 7 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self->priv = FOLDERS_BRANCH_GET_PRIVATE (self);
#line 8 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = gee_hash_map_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, FOLDERS_TYPE_SIDEBAR_ENTRY, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
#line 8 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self->priv->entries = _tmp0_;
#line 1504 "Branch.c"
}


static void folders_branch_finalize (GObject * obj) {
	FoldersBranch * self;
#line 7 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLDERS_TYPE_BRANCH, FoldersBranch);
#line 1512 "Branch.c"
	{
		GeeIterator* _sources_it = NULL;
		MediaCollectionRegistry* _tmp0_;
		MediaCollectionRegistry* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp1_ = _tmp0_;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp3_ = _tmp2_;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp5_ = _tmp4_;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (_tmp3_);
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_sources_it = _tmp5_;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		while (TRUE) {
#line 1541 "Branch.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			MediaSourceCollection* sources = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			MediaSourceCollection* _tmp10_;
			guint _tmp11_;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp6_ = _sources_it;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			if (!_tmp7_) {
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
				break;
#line 1557 "Branch.c"
			}
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp8_ = _sources_it;
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			sources = (MediaSourceCollection*) _tmp9_;
#line 31 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp10_ = sources;
#line 31 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp11_, NULL, FALSE);
#line 31 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, 0, NULL, (GCallback) _folders_branch_on_media_contents_altered_data_collection_contents_altered, self);
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_data_collection_unref0 (sources);
#line 1573 "Branch.c"
		}
#line 30 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (_sources_it);
#line 1577 "Branch.c"
	}
#line 8 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (self->priv->entries);
#line 10 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (self->priv->home_dir);
#line 7 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	G_OBJECT_CLASS (folders_branch_parent_class)->finalize (obj);
#line 1585 "Branch.c"
}


GType folders_branch_get_type (void) {
	static volatile gsize folders_branch_type_id__volatile = 0;
	if (g_once_init_enter (&folders_branch_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FoldersBranchClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folders_branch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FoldersBranch), 0, (GInstanceInitFunc) folders_branch_instance_init, NULL };
		GType folders_branch_type_id;
		folders_branch_type_id = g_type_register_static (SIDEBAR_TYPE_BRANCH, "FoldersBranch", &g_define_type_info, 0);
		g_once_init_leave (&folders_branch_type_id__volatile, folders_branch_type_id);
	}
	return folders_branch_type_id__volatile;
}


FoldersRoot* folders_root_construct (GType object_type) {
	FoldersRoot * self = NULL;
#line 144 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = (FoldersRoot*) sidebar_header_construct (object_type, _ ("Folders"), TRUE);
#line 143 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return self;
#line 1607 "Branch.c"
}


FoldersRoot* folders_root_new (void) {
#line 143 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return folders_root_construct (FOLDERS_TYPE_ROOT);
#line 1614 "Branch.c"
}


static void folders_root_class_init (FoldersRootClass * klass) {
#line 142 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_root_parent_class = g_type_class_peek_parent (klass);
#line 1621 "Branch.c"
}


static void folders_root_instance_init (FoldersRoot * self) {
}


GType folders_root_get_type (void) {
	static volatile gsize folders_root_type_id__volatile = 0;
	if (g_once_init_enter (&folders_root_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FoldersRootClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folders_root_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FoldersRoot), 0, (GInstanceInitFunc) folders_root_instance_init, NULL };
		GType folders_root_type_id;
		folders_root_type_id = g_type_register_static (SIDEBAR_TYPE_HEADER, "FoldersRoot", &g_define_type_info, 0);
		g_once_init_leave (&folders_root_type_id__volatile, folders_root_type_id);
	}
	return folders_root_type_id__volatile;
}


FoldersSidebarEntry* folders_sidebar_entry_construct (GType object_type, GFile* dir) {
	FoldersSidebarEntry * self = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
#line 169 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_val_if_fail (G_IS_FILE (dir), NULL);
#line 169 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = (FoldersSidebarEntry*) sidebar_simple_page_entry_construct (object_type);
#line 170 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = dir;
#line 170 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_sidebar_entry_set_dir (self, _tmp0_);
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = dir;
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp2_ = g_file_get_path (_tmp1_);
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp3_ = _tmp2_;
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp4_ = g_utf8_collate_key_for_filename (_tmp3_, (gssize) -1);
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp5_ = _tmp4_;
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_sidebar_entry_set_collation (self, _tmp5_);
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_free0 (_tmp5_);
#line 171 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_free0 (_tmp3_);
#line 169 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return self;
#line 1675 "Branch.c"
}


FoldersSidebarEntry* folders_sidebar_entry_new (GFile* dir) {
#line 169 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return folders_sidebar_entry_construct (FOLDERS_TYPE_SIDEBAR_ENTRY, dir);
#line 1682 "Branch.c"
}


static gchar* folders_sidebar_entry_real_get_sidebar_name (SidebarSimplePageEntry* base) {
	FoldersSidebarEntry * self;
	gchar* result = NULL;
	GFile* _tmp0_;
	gchar* _tmp1_;
#line 174 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 175 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_dir;
#line 175 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = g_file_get_basename (_tmp0_);
#line 175 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = _tmp1_;
#line 175 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1701 "Branch.c"
}


static gchar* folders_sidebar_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base) {
	FoldersSidebarEntry * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_;
	gint _tmp2_;
	gchar* _tmp5_;
#line 178 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = folders_sidebar_entry_get_count (self);
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp2_ = _tmp1_;
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp2_ == 0) {
#line 1720 "Branch.c"
		const gchar* _tmp3_;
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp3_ = folders_icon;
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp0_ = _tmp3_;
#line 1726 "Branch.c"
	} else {
		const gchar* _tmp4_;
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp4_ = folders_have_photos_icon;
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp0_ = _tmp4_;
#line 1733 "Branch.c"
	}
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp5_ = g_strdup (_tmp0_);
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = _tmp5_;
#line 179 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1741 "Branch.c"
}


static gchar* folders_sidebar_entry_real_to_string (SidebarSimplePageEntry* base) {
	FoldersSidebarEntry * self;
	gchar* result = NULL;
	GFile* _tmp0_;
	gchar* _tmp1_;
#line 182 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 183 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_dir;
#line 183 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = g_file_get_path (_tmp0_);
#line 183 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = _tmp1_;
#line 183 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1760 "Branch.c"
}


static gboolean folders_sidebar_entry_real_expand_on_select (SidebarExpandableEntry* base) {
	FoldersSidebarEntry * self;
	gboolean result = FALSE;
#line 186 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 187 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = TRUE;
#line 187 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1773 "Branch.c"
}


static Page* folders_sidebar_entry_real_create_page (SidebarSimplePageEntry* base) {
	FoldersSidebarEntry * self;
	Page* result = NULL;
	GFile* _tmp0_;
	FoldersPage* _tmp1_;
#line 190 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 191 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_dir;
#line 191 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = folders_page_new (_tmp0_);
#line 191 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_object_ref_sink (_tmp1_);
#line 191 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PAGE, Page);
#line 191 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1794 "Branch.c"
}


GFile* folders_sidebar_entry_get_dir (FoldersSidebarEntry* self) {
	GFile* result;
	GFile* _tmp0_;
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_val_if_fail (FOLDERS_IS_SIDEBAR_ENTRY (self), NULL);
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_dir;
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = _tmp0_;
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1809 "Branch.c"
}


static void folders_sidebar_entry_set_dir (FoldersSidebarEntry* self, GFile* value) {
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_SIDEBAR_ENTRY (self));
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (folders_sidebar_entry_get_dir (self) != value) {
#line 1818 "Branch.c"
		GFile* _tmp0_;
		GFile* _tmp1_;
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp0_ = value;
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_object_unref0 (self->priv->_dir);
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		self->priv->_dir = _tmp1_;
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		g_object_notify ((GObject *) self, "dir");
#line 1831 "Branch.c"
	}
}


const gchar* folders_sidebar_entry_get_collation (FoldersSidebarEntry* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_val_if_fail (FOLDERS_IS_SIDEBAR_ENTRY (self), NULL);
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_collation;
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = _tmp0_;
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1847 "Branch.c"
}


static void folders_sidebar_entry_set_collation (FoldersSidebarEntry* self, const gchar* value) {
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_SIDEBAR_ENTRY (self));
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (g_strcmp0 (value, folders_sidebar_entry_get_collation (self)) != 0) {
#line 1856 "Branch.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp0_ = value;
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_free0 (self->priv->_collation);
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		self->priv->_collation = _tmp1_;
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		g_object_notify ((GObject *) self, "collation");
#line 1869 "Branch.c"
	}
}


gint folders_sidebar_entry_get_count (FoldersSidebarEntry* self) {
	gint result;
	gint _tmp0_;
#line 154 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_val_if_fail (FOLDERS_IS_SIDEBAR_ENTRY (self), 0);
#line 155 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_count;
#line 155 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	result = _tmp0_;
#line 155 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	return result;
#line 1885 "Branch.c"
}


void folders_sidebar_entry_set_count (FoldersSidebarEntry* self, gint value) {
	gint prev_count = 0;
	gint _tmp0_;
	gint _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_;
#line 158 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_return_if_fail (FOLDERS_IS_SIDEBAR_ENTRY (self));
#line 159 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp0_ = self->priv->_count;
#line 159 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	prev_count = _tmp0_;
#line 160 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp1_ = value;
#line 160 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self->priv->_count = _tmp1_;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_tmp4_ = prev_count;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp4_ == 0) {
#line 1910 "Branch.c"
		gint _tmp5_;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp5_ = self->priv->_count;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp3_ = _tmp5_ == 1;
#line 1916 "Branch.c"
	} else {
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp3_ = FALSE;
#line 1920 "Branch.c"
	}
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp3_) {
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp2_ = TRUE;
#line 1926 "Branch.c"
	} else {
		gboolean _tmp6_ = FALSE;
		gint _tmp7_;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp7_ = prev_count;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		if (_tmp7_ == 1) {
#line 1934 "Branch.c"
			gint _tmp8_;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp8_ = self->priv->_count;
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp6_ = _tmp8_ == 0;
#line 1940 "Branch.c"
		} else {
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
			_tmp6_ = FALSE;
#line 1944 "Branch.c"
		}
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp2_ = _tmp6_;
#line 1948 "Branch.c"
	}
#line 163 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	if (_tmp2_) {
#line 1952 "Branch.c"
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 164 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp9_ = sidebar_simple_page_entry_get_sidebar_icon (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry));
#line 164 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_tmp10_ = _tmp9_;
#line 164 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_ENTRY, SidebarEntry), "sidebar-icon-changed", _tmp10_);
#line 164 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		_g_free0 (_tmp10_);
#line 1963 "Branch.c"
	}
#line 158 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_object_notify ((GObject *) self, "count");
#line 1967 "Branch.c"
}


static void folders_sidebar_entry_class_init (FoldersSidebarEntryClass * klass) {
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_sidebar_entry_parent_class = g_type_class_peek_parent (klass);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_type_class_add_private (klass, sizeof (FoldersSidebarEntryPrivate));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_name = (gchar* (*) (SidebarSimplePageEntry *)) folders_sidebar_entry_real_get_sidebar_name;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_icon = (gchar* (*) (SidebarSimplePageEntry *)) folders_sidebar_entry_real_get_sidebar_icon;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->to_string = (gchar* (*) (SidebarSimplePageEntry *)) folders_sidebar_entry_real_to_string;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->create_page = (Page* (*) (SidebarSimplePageEntry *)) folders_sidebar_entry_real_create_page;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_folders_sidebar_entry_get_property;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_folders_sidebar_entry_set_property;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = folders_sidebar_entry_finalize;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLDERS_SIDEBAR_ENTRY_DIR_PROPERTY, g_param_spec_object ("dir", "dir", "dir", g_file_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLDERS_SIDEBAR_ENTRY_COLLATION_PROPERTY, g_param_spec_string ("collation", "collation", "collation", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLDERS_SIDEBAR_ENTRY_COUNT_PROPERTY, g_param_spec_int ("count", "count", "count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1996 "Branch.c"
}


static void folders_sidebar_entry_sidebar_expandable_entry_interface_init (SidebarExpandableEntryIface * iface) {
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	folders_sidebar_entry_sidebar_expandable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	iface->expand_on_select = (gboolean (*) (SidebarExpandableEntry *)) folders_sidebar_entry_real_expand_on_select;
#line 2005 "Branch.c"
}


static void folders_sidebar_entry_instance_init (FoldersSidebarEntry * self) {
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self->priv = FOLDERS_SIDEBAR_ENTRY_GET_PRIVATE (self);
#line 152 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self->priv->_count = 0;
#line 2014 "Branch.c"
}


static void folders_sidebar_entry_finalize (GObject * obj) {
	FoldersSidebarEntry * self;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 149 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_object_unref0 (self->priv->_dir);
#line 150 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	_g_free0 (self->priv->_collation);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	G_OBJECT_CLASS (folders_sidebar_entry_parent_class)->finalize (obj);
#line 2028 "Branch.c"
}


GType folders_sidebar_entry_get_type (void) {
	static volatile gsize folders_sidebar_entry_type_id__volatile = 0;
	if (g_once_init_enter (&folders_sidebar_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FoldersSidebarEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folders_sidebar_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FoldersSidebarEntry), 0, (GInstanceInitFunc) folders_sidebar_entry_instance_init, NULL };
		static const GInterfaceInfo sidebar_expandable_entry_info = { (GInterfaceInitFunc) folders_sidebar_entry_sidebar_expandable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType folders_sidebar_entry_type_id;
		folders_sidebar_entry_type_id = g_type_register_static (SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, "FoldersSidebarEntry", &g_define_type_info, 0);
		g_type_add_interface_static (folders_sidebar_entry_type_id, SIDEBAR_TYPE_EXPANDABLE_ENTRY, &sidebar_expandable_entry_info);
		g_once_init_leave (&folders_sidebar_entry_type_id__volatile, folders_sidebar_entry_type_id);
	}
	return folders_sidebar_entry_type_id__volatile;
}


static void _vala_folders_sidebar_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	FoldersSidebarEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	switch (property_id) {
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		case FOLDERS_SIDEBAR_ENTRY_DIR_PROPERTY:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		g_value_set_object (value, folders_sidebar_entry_get_dir (self));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		case FOLDERS_SIDEBAR_ENTRY_COLLATION_PROPERTY:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		g_value_set_string (value, folders_sidebar_entry_get_collation (self));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		case FOLDERS_SIDEBAR_ENTRY_COUNT_PROPERTY:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		g_value_set_int (value, folders_sidebar_entry_get_count (self));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 2069 "Branch.c"
		default:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 2075 "Branch.c"
	}
}


static void _vala_folders_sidebar_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	FoldersSidebarEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FOLDERS_TYPE_SIDEBAR_ENTRY, FoldersSidebarEntry);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
	switch (property_id) {
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		case FOLDERS_SIDEBAR_ENTRY_DIR_PROPERTY:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		folders_sidebar_entry_set_dir (self, g_value_get_object (value));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		case FOLDERS_SIDEBAR_ENTRY_COLLATION_PROPERTY:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		folders_sidebar_entry_set_collation (self, g_value_get_string (value));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		case FOLDERS_SIDEBAR_ENTRY_COUNT_PROPERTY:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		folders_sidebar_entry_set_count (self, g_value_get_int (value));
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 2103 "Branch.c"
		default:
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 148 "/home/jens/Source/shotwell/src/folders/Branch.vala"
		break;
#line 2109 "Branch.c"
	}
}



